# LeagueLibrary

LeagueLibrary is a library for Python3 based on the origial Riot Games API.

![LeagueLibrary Version](https://img.shields.io/badge/LeagueLibrary%20Version-2021.08.15-brightgreen)
![LeagueLibrary Release](https://img.shields.io/badge/LeagueLibrary%20Release-2-brightgreen)
